==> scribus_1.2.1.orig.tar.gz: scribus-1.2.1/scribus/bookpalette.h <==
/***************************************************************************
                          bookpalette.h  -  description
                             -------------------
    begin                : Son Jan 19 2003
    copyright            : (C) 2003 by Franz Schmid
    email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef BOOKPALETTE_H
#define BOOKPALETTE_H

#include <qdialog.h>
#include <qlayout.h>
#include <bookmwin.h>
/**
  *@author Franz Schmid
  */

class BookPalette : public QDialog
{
	Q_OBJECT

public:
	BookPalette(QWidget* parent);
	~BookPalette() {};
	void keyPressEvent(QKeyEvent *k);
	void closeEvent(QCloseEvent *ce);
	BookMView	*BView;

signals:
	void ToggleAllPalettes();
	void Schliessen();

protected:
	QVBoxLayout* PaletteLayout;

protected slots:
	virtual void reject();
};

#endif

==> scribus_1.3.3.11.dfsg.orig.tar.gz: scribus-1.3.3.11.dfsg/scribus/bookpalette.h <==
/*
For general Scribus (>=1.3.2) copyright and licensing information please refer
to the COPYING file provided with the program. Following this notice may exist
a copyright and/or license notice that predates the release of Scribus 1.3.2
for which a new license (GPL+exception) is in place.
*/
/***************************************************************************
                          bookpalette.h  -  description
                             -------------------
    begin                : Son Jan 19 2003
    copyright            : (C) 2003 by Franz Schmid
    email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef BOOKPALETTE_H
#define BOOKPALETTE_H

#include <qlayout.h>
#include "scribusapi.h"
#include "scrpalettebase.h"
#include "bookmwin.h"
/**
  *@author Franz Schmid
  */

/*! \brief A Bookmark Palette */
class SCRIBUS_API BookPalette : public ScrPaletteBase
{
	Q_OBJECT

public:
	/*!
	\fn BookPalette::BookPalette(QWidget* parent)
	\author Franz Schmid
	\date
	\brief Constructor for Bookmark Palette
	\param parent Parent Window
	\retval None
	*/
	BookPalette(QWidget* parent);
	~BookPalette() {};
	//void keyPressEvent(QKeyEvent *k);
	//void closeEvent(QCloseEvent *ce);
	BookMView	*BView;
	
public slots:
	void languageChange();

signals:
	//void ToggleAllPalettes();
	//void Schliessen();

protected:
	QVBoxLayout* PaletteLayout;

protected slots:
	//virtual void reject();
};

#endif
